==> errorhandling-1.0.0.tgz: package/test/ResponseEntityTest.js <==
var chai = require('chai');
var expect = chai.expect;
var chaiHttp = require('chai-http');

var responseEntity = require('../utility/ResponseEntity.js');

chai.use(chaiHttp);

/*
** Test cases for Sequelize error
*/
describe('Check for Seqelize error', function () {
    it('Should return a Sequelize database error ', function (done) {
        var resObj = {
            "module_name": "US",   //US for User Service
            "code": 1000,          //code 1000 is defined for sequelize error
            "error": {
                "name": "SequelizeDatabaseError",
                "message": "database error"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-501');
            done();
        })
    });

    it('Should return a Sequelize validation error ', function (done) {
        var resObj = {
            "module_name": "US",   //US for User Service
            "code": 1000,          //code 1000 is defined for sequelize error
            "error": {
                "name": "SequelizeValidationError",
                "message": "Invalid input paramters"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-422');
            done();
        })
    });

    it('Should return a Sequelize error', function (done) {
        var resObj = {
            "module_name": "US",   //US for User Service
            "code": 1000,          //code 1000 is defined for sequelize error
            "error": {
                "name": "SequelizeError",
                "message": "connection close"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-501');
            done();
        })
    });
});

/*
** Test cases for cassandra database errors
*/
describe('Check for cassandra error', function () {
    it('Should return a cassandra validation error', function (done) {
        var resObj = {
            "module_name": "PS",   //PS for Patient Service
            "code": 2000,          //code 2000 is defined for cassandra errors
            "error": {
                "name": "apollo.model.validator.invalidvalue",
                "message": "validation error"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-422');
            done();
        })
    });

    it('Should return a cassandra database error', function (done) {
        var resObj = {
            "module_name": "PS",   //PS for Patient Service
            "code": 2000,          //code 2000 is defined for cassandra errors
            "error": {
                "name": "CassandraError",
                "message": "connection close"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-501');
            done();
        })
    });
});

/*
** Test cases for Input validation errors
*/
describe('Check for input validation error', function () {
    it('Should return an error', function (done) {
        var resObj = {
            "module_name": "PS",   //PS for Patient Service
            "code": 422,          //code 2000 is defined for cassandra errors
            "message": "Invalid query parameters"
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-422');
            done();
        })
    });
});

/*
** Test cases for success response
*/
describe('Check for success response object', function () {
    it('Should return a successfully created response ', function (done) {
        var resObj = {
            "module_name": "US",   //US for User Service
            "code": 201,
            "message": "User created successfully",
            "data": {
                "id": 13
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-201');
            done();
        })
    });

    it('Should return a success response ', function (done) {
        var resObj = {
            "module_name": "US",   //US for User Service
            "code": 200,
            "message": "successfully fetched records",
            "data": {
                "id": 13,
                "name": "shiwani",
                "mobNo": "9876543212"
            }
        };

        responseEntity.sendResponse(resObj, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-200');
            done();
        })
    });
});

==> errorhandling-2.0.0.tgz: package/test/ResponseEntityTest.js <==
var chai = require('chai');
var expect = chai.expect;
var chaiHttp = require('chai-http');

var responseEntity = require('../utility/ResponseEntity.js');

chai.use(chaiHttp);

/*
** Test cases for Sequelize error
*/
describe('Check for Seqelize error', function () {
    it('Should return a Sequelize database error ', function (done) {
         var error= {
                "name": "SequelizeDatabaseError",
                "message": "database error"
            }        

        responseEntity.sendResponse("US",1000,null,null,error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-501');
            done();
        })
    });

    it('Should return a Sequelize validation error ', function (done) {
            var error= {
                "name": "SequelizeValidationError",
                "message": "Invalid input paramters"
            }        

        responseEntity.sendResponse("US",1000,null,null,error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-422');
            done();
        })
    });

    it('Should return a Sequelize error', function (done) {
            
            var error= {
                "name": "SequelizeError",
                "message": "connection close"
            }        

        responseEntity.sendResponse("US",1000,null,null,error, function (result) {			
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-501');
            done();
        })
    });
});

/*
** Test cases for cassandra database errors
*/
describe('Check for cassandra error', function () {
    it('Should return a cassandra validation error', function (done) {
            var error= {
                "name": "apollo.model.validator.invalidvalue",
                "message": "validation error"
            }        

        responseEntity.sendResponse("PS",2000,null,null,error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-422');
            done();
        })
    });

    it('Should return a cassandra database error', function (done) {
            var error= {
                "name": "CassandraError",
                "message": "connection close"
            }        

        responseEntity.sendResponse("PS",2000,null,null,error, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('PS-501');
            done();
        })
    });
});

/*
** Test cases for Input validation errors
*/
describe('Check for input validation error', function () {
    it('Should return an error', function (done) {       
        responseEntity.sendResponse("PS",422,"Invalid query parameters",null,null, function (result) {			
            JSON.stringify(result);			
            expect(result.code).to.be.a('string').eq('PS-422');
            done();
        })
    });
});

/*
** Test cases for success response
*/
describe('Check for success response object', function () {
    it('Should return a successfully created response ', function (done) {
            var data={
                "id": 13
            }        

        responseEntity.sendResponse("US",201,"User created Successfully",data,null, function (result) {			
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-201');
            done();
        })
    });

    it('Should return a success response ', function (done) {
            var data={
                "id": 13,
                "name": "shiwani",
                "mobNo": "9876543212"
            }        

        responseEntity.sendResponse("US",200,"Successfully fetched records",data,null, function (result) {
            JSON.stringify(result);
            expect(result.code).to.be.a('string').eq('US-200');
            done();
        })
    });
});
